@@ -1,6 +1,7 @@
 """Compatibility wrapper for HMMER binaries and output.
 """
 import abc
+import atexit
 import collections
 import configparser
 import contextlib
@@ -15,23 +16,20 @@ import tempfile
 import typing
 from typing import Callable, Dict, Optional, Iterable, Iterator, List, Mapping, Type, Sequence
 
-import pkg_resources
 import pyhmmer
 from Bio import SeqIO
+from pyhmmer.hmmer import hmmsearch
 
-from ._worker import hmmsearch
 from .._meta import requires
 from ..model import Gene, Domain
 from ..interpro import InterPro
 
+try:
+    import importlib.resources as importlib_resources
+except ImportError:
+    import importlib_resources
 
-if typing.TYPE_CHECKING:
-    from Bio.SeqRecord import SeqRecord
-
-    _T = typing.TypeVar("_T", bound="DomainRow")
-
-
-__all__ = ["DomainRow", "HMM", "HMMER", "PyHMMER", "embedded_hmms"]
+__all__ = ["DomainAnnotator", "HMM", "PyHMMER", "embedded_hmms"]
 
 
 class HMM(typing.NamedTuple):
@@ -100,28 +98,27 @@ class PyHMMER(DomainAnnotator):
         # collect genes and build an index of genes by protein id
         gene_index = collections.OrderedDict([(gene.id, gene) for gene in genes])
 
-        # group genes by contig
-        by_source  = collections.defaultdict(list)
-        for gene in gene_index.values():
-            by_source[gene.source.id].append(gene)
-
-        # convert to Easel sequences, grouped by contig
+        # convert proteins to Easel sequences
         esl_abc = pyhmmer.easel.Alphabet.amino()
         esl_sqs = [
-            [
-                pyhmmer.easel.TextSequence(
-                    name=gene.protein.id.encode(),
-                    sequence=str(gene.protein.seq)
-                ).digitize(esl_abc)
-                for gene in contig_genes
-            ]
-            for contig_genes in by_source.values()
+            pyhmmer.easel.TextSequence(
+                name=gene.protein.id.encode(),
+                sequence=str(gene.protein.seq)
+            ).digitize(esl_abc)
+            for gene in genes
         ]
 
-        # Run HMMER subprocess.run(cmd, stdout=subprocess.DEVNULL).check_returncode()
+        # Run search pipeline using the HMM
         with pyhmmer.plan7.HMMFile(self.hmm.path) as hmm_file:
             cpus = 0 if self.cpus is None else self.cpus
-            hmms_hits = hmmsearch(hmm_file, esl_sqs, cpus=cpus, callback=progress)
+            hmms_hits = hmmsearch(
+                hmm_file,
+                esl_sqs,
+                cpus=cpus,
+                callback=progress,
+                Z=len(esl_sqs),
+                domZ=len(esl_sqs)
+            )
 
             # Load InterPro metadata for the annotation
             interpro = InterPro.load()
@@ -156,11 +153,22 @@ class PyHMMER(DomainAnnotator):
 def embedded_hmms() -> Iterator[HMM]:
     """Iterate over the embedded HMMs that are shipped with GECCO.
     """
-    for ini in glob.glob(pkg_resources.resource_filename(__name__, "*.ini")):
-        cfg = configparser.ConfigParser()
-        cfg.read(ini)
+    for filename in importlib_resources.contents(__name__):
 
+        if not filename.endswith(".ini"):
+            continue
+
+        ini_ctx = importlib_resources.path(__name__, filename)
+        ini_path = ini_ctx.__enter__()
+        atexit.register(ini_ctx.__exit__, None, None, None)
+
+        cfg = configparser.ConfigParser()
+        cfg.read(ini_path)
         args = dict(cfg.items("hmm"))
         args["size"] = int(args["size"])
 
-        yield HMM(path=ini.replace(".ini", ".h3m"), **args)
+        hmm_ctx = importlib_resources.path(__name__, filename.replace(".ini", ".h3m"))
+        hmm_path = hmm_ctx.__enter__()
+        atexit.register(hmm_ctx.__exit__, None, None, None)
+
+        yield HMM(path=os.fspath(hmm_path), **args)
